from screenmanager import *
from fontdrawer import *
from physicsobject import *
import pygame
from pygame.locals import *

PI = 3.1415926535

class EditScreen(Screen):

    #Set up the screen by loading the current level
    def __init__(self, screenManager, levelNumber):
        Screen.__init__(self, screenManager)

        self.fd = FontDrawer()

        self.background = pygame.image.load("sprites/bg.png").convert()

        self.poc = PhysicsObjectCreator(480)
        
        self.ground = self.poc.createObjectByID(-1,320,464, True)

        self.currentid = 0

        self.currentBody = self.poc.createObjectByID(self.currentid, 40,40, True)

        self.placeAngle = 0

        self.levelNumber = levelNumber

        self.poc.loadState(self.levelNumber)

    #Update physics and delete objects that could not be deleted earlier
    def update(self, timestep):
        self.poc.update(timestep, 10, 10)
        self.poc.deleteObjects()
        
    #Draw all currently existing physics objects
    def draw(self, screen):
        screen.blit(self.background, self.background.get_rect())

        for obj in self.poc.getObjectList():
            if obj.getID() >= 0:
                obj.draw(screen)

        self.fd.drawCachedText(screen, "Arial", "Left/Right change block. Up / Down rotates. Plus sign toggles breaking. Click to place.", 10,10,18,(0,0,0),True)
        self.fd.drawCachedText(screen, "Arial", "Level #" + str(self.levelNumber) + "Enter saves. Q clears level. Z/X change level. Backspace goes to the menu.",10,460,18,(0,0,0),True)
        
        
    #Process keyboard input for the title screen such as moving the selected menu item up and down
    def keyinput(self, keypress, keyup, mousepress, mouseup):
        for p in mousepress:
            if p == 1:
                posx, posy = pygame.mouse.get_pos()
                self.poc.createObjectByID(self.currentid, posx, posy, False, (PI/4)*self.placeAngle)
            if p == 3:
                posx, posy = pygame.mouse.get_pos()
                body = self.poc.getObjectAtPoint(posx, posy)
                if body:
                    self.poc.addObjectToDelete(body)

        for key in keypress:
            if key == K_LEFT:
                self.currentid += 1
                if (self.currentid >= self.poc.getIDCount()):
                    self.currentid = 0
            elif key == K_RIGHT:
                self.currentid -= 1
                if (self.currentid < 0):
                    self.currentid = self.poc.getIDCount()-1
            elif key == K_RETURN:
                self.poc.saveCurrentState(self.levelNumber)
            elif key == K_MINUS:
                self.poc.loadState(self.levelNumber)
            elif key == K_EQUALS:
                self.poc.toggleHPEnabled()
            elif key== K_UP:
                self.placeAngle += 1
                if (self.currentid >= 8):
                    self.placeAngle = 0
            elif key== K_DOWN:
                self.placeAngle -= 1
                if (self.placeAngle < 0):
                    self.placeAngle = 7
            elif key==K_z:
                if self.levelNumber > 0:
                    self.manager.removeTopScreen()
                    self.manager.addScreen(EditScreen(self.manager, self.levelNumber-1))
            elif key==K_x:
                self.manager.removeTopScreen()
                self.manager.addScreen(EditScreen(self.manager, self.levelNumber+1))
            elif key==K_q:
                for obj in self.poc.getObjectList():
                    if not obj.getIsStatic():
                        self.poc.addObjectToDelete(obj)
            elif key==K_BACKSPACE:
                self.manager.removeTopScreen() #Return to the main menu

            #This redraws the preview in the upper left corner if it changes
            if (key == K_LEFT) or (key == K_RIGHT) or (key == K_UP) or (key == K_DOWN):
                self.poc.addObjectToDelete(self.currentBody)
                self.currentBody = self.poc.createObjectByID(self.currentid, 40,40, True,(PI/4)*self.placeAngle)
                
