from screenmanager import *
from fontdrawer import *
from physicsobject import *
from winscreen import *
from pausescreen import *
import pygame
from pygame.locals import *
import math

#States the slingshot can be in
LOADED = 1
PRIMED = 2
FIRING = 3

#Slingshot aiming position
SLING_X = 90
SLING_Y = 280

class MainScreen(Screen):

    #Set up the main screen and load the current level
    def __init__(self, screenManager, levelNumber, totalBlocksUsed):
        Screen.__init__(self, screenManager)

        self.totalBlocksUsed = totalBlocksUsed
        
        self.fd = FontDrawer()

        self.background = pygame.image.load("sprites/bg.png").convert()
        self.slingshot = pygame.image.load("sprites/slingshot.png").convert()
        self.slingshot.set_colorkey((255,255,255))

        self.poc = PhysicsObjectCreator(480)
        
        self.ground = self.poc.createObjectByID(-1,320,464, True)
        self.wall = self.poc.createObjectByID(-2,656,240, True)
        self.wall2 = self.poc.createObjectByID(-2,-16,240, True)

        self.levelNumber = levelNumber

        self.poc.loadState(self.levelNumber)

        self.slingState = LOADED

        self.lastX = SLING_X
        self.lastY = SLING_Y
        self.impulseX = 0
        self.impulseY = 0

    #Update physics and fire sling if needed
    def update(self, timestep):
        #Count the bad purple rectangles and if there are none left go to the next level
        badcount = 0
        for obj in self.poc.getObjectList():
            if obj.getID() == 2:
                badcount+=1
        if (badcount == 0):
            self.manager.removeTopScreen()
            if self.poc.loadState(self.levelNumber+1):
                self.manager.addScreen(MainScreen(self.manager, self.levelNumber+1, self.totalBlocksUsed))
            else:
                self.manager.addScreen(WinScreen(self.manager, self.totalBlocksUsed))
        
        if self.slingState == FIRING:
            self.poc.createObjectByID(3, self.lastX, self.lastY, False, 0).applyImpulse((self.impulseX)*1.5,(-self.impulseY)*1.5)
            self.slingState = LOADED
        
        self.poc.update(timestep, 10, 10)
        self.poc.deleteObjects()
        
    #Draw all physics objects and the ammo before it is launched
    def draw(self, screen):
        screen.blit(self.background, self.background.get_rect())
        screen.blit(self.slingshot, (SLING_X-49,SLING_Y-22))

        if self.slingState == LOADED:
            pygame.draw.rect(screen, (255,0,0), pygame.Rect((SLING_X-12,SLING_Y-12), (23,23)))

        if self.slingState == PRIMED:
            posx,posy = pygame.mouse.get_pos()

            #Make a vector from the center of the slingshot to the center of the block being fired
            vecX = SLING_X-posx
            vecY = SLING_Y-posy
            
            invMagnitude = 1.0/(math.sqrt((vecX)**2+(vecY)**2))

            #If the block is more than 70 pixels away make it at the same angle but limit the magnitude of the vector to 70
            if (invMagnitude < (1.0/70)):
                vecX *= invMagnitude * 70
                vecY *= invMagnitude * 70

            self.impulseX = vecX
            self.impulseY = vecY
            
            self.lastX = SLING_X-vecX
            self.lastY = SLING_Y-vecY
            #Draw the box
            pygame.draw.rect(screen, (255,0,0), pygame.Rect((self.lastX-12,self.lastY-12), (23,23)))
            
            #Draw the band
            pygame.draw.line(screen, (200,0,0), (SLING_X,SLING_Y), (self.lastX,self.lastY), 4)


        #Draw all objects
        for obj in self.poc.getObjectList():
            if obj.getID() >= 0:
                obj.draw(screen)

        self.fd.drawText(screen, "Arial", "Total Blocks Used: " + str(self.totalBlocksUsed) + "Backspace goes to the menu. Space pauses.",10,460,18,(0,0,0),True)
        
    #Process input
    def keyinput(self, keypress, keyup, mousepress, mouseup):
        for key in keyup:
            if key==K_BACKSPACE:
                self.manager.removeTopScreen() #Return to the main menu
            if key==K_SPACE:
                self.manager.addScreen(PauseScreen(self.manager)) #Pause

        for mb in mousepress:
            if mb == 1:
                self.slingState = PRIMED

        for mb in mouseup:
            if mb == 1:
                self.slingState = FIRING
                self.totalBlocksUsed += 1
