from screenmanager import *
from fontdrawer import *
from maingame import *
from leveleditor import *
from storyscreen import *
import pygame
from pygame.locals import *

class TitleScreen(Screen):

    #Set up the title screen
    def __init__(self, screenManager):
        Screen.__init__(self, screenManager)

        self.fd = FontDrawer()

        self.background = pygame.image.load("sprites/bg.png")

        self.selectedMenu = 0
        self.menuItems = ["Start Game", "Editor", "Story", "Exit"]

    #Draw the menu options to the screen
    def draw(self, screen):
        screen.blit(self.background, self.background.get_rect())

        i = 0
        for item in self.menuItems:
            self.fd.drawCachedText(screen, "Arial", item, 64,240 + i * 50,50,(150,150,150),True)
            i+=1

        self.fd.drawCachedText(screen, "Arial", "Block Attack", 20,20,90,(255,0,0),True)
        
        self.fd.drawCachedText(screen, "Arial", self.menuItems[self.selectedMenu], 64,240 + self.selectedMenu * 50,50,(255,255,255),True)

        self.fd.drawCachedText(screen, "Arial", "Press Up / Down to move and Enter to select",10,10,18,(0,0,0),True)

    #Respond to the user selecting a menu option
    def processMenu(self):
        if self.selectedMenu == 0:
            self.manager.addScreen(MainScreen(self.manager, 0, 0))
        elif self.selectedMenu == 1:
            self.manager.addScreen(EditScreen(self.manager, 0))
        elif self.selectedMenu == 2:
            self.manager.addScreen(StoryScreen(self.manager))
        elif self.selectedMenu == 3:
            self.manager.removeTopScreen() #Removing this screen exits the game

    #Process keyboard input for the title screen such as moving the selected menu item up and down
    def keyinput(self, keypress, keyup, mousepress, mouseup):
        for key in keypress:
            if key == K_UP:
                self.selectedMenu -= 1
                if self.selectedMenu < 0:
                    self.selectedMenu = len(self.menuItems) - 1
            elif key == K_DOWN:
                self.selectedMenu += 1
                if self.selectedMenu >= len(self.menuItems):
                    self.selectedMenu = 0
            elif key == K_RETURN:
                self.processMenu()

#This is where the program starts executing so intialize pygame and create the title screen then run it
def main():
    pygame.init()
    sm = ScreenManager(60,640,480)

    sm.addScreen(TitleScreen(sm))
    sm.run()
    pygame.quit()

main()
